# -*- coding: utf-8 -*-
"""
Created on Fri Oct 25 12:11:07 2019

@author: Riku_L

Script to create the conceptual figure for the relations of leniency, X and Z.
"""

import matplotlib.pyplot as plt
import numpy as np

plt.switch_backend('agg')

def gradient_image(ax, extent, direction=0.3, cmap_range=(0, 1), **kwargs):
    """
    Draw a gradient image based on a colormap.

    Parameters
    ----------
    ax : Axes
        The axes to draw on.
    extent
        The extent of the image as (xmin, xmax, ymin, ymax).
        By default, this is in Axes coordinates but may be
        changed using the *transform* kwarg.
    direction : float
        The direction of the gradient. This is a number in
        range 0 (=vertical) to 1 (=horizontal).
    cmap_range : float, float
        The fraction (cmin, cmax) of the colormap that should be
        used for the gradient, where the complete colormap is (0, 1).
    **kwargs
        Other parameters are passed on to `.Axes.imshow()`.
        In particular useful is *cmap*.
    """
    phi = direction * np.pi / 2
    v = np.array([np.cos(phi), np.sin(phi)])
    X = np.array([[v @ [1, 0], v @ [1, 1]],
                  [v @ [0, 0], v @ [0, 1]]])
    a, b = cmap_range
    X = a + (b - a) / X.max() * X
    im = ax.imshow(X, extent=extent, interpolation='bicubic',
                   vmin=0, vmax=1, **kwargs)
    return im

def arrowed_spines(fig, ax):

    xmin, xmax = ax.get_xlim() 
    ymin, ymax = ax.get_ylim()

    # removing the default axis on all sides:
    for side in ['bottom','right','top','left']:
        ax.spines[side].set_visible(False)

    # removing the axis ticks
    plt.xticks([]) # labels 
    plt.yticks([])
    ax.xaxis.set_ticks_position('none') # tick markers
    ax.yaxis.set_ticks_position('none')

    # get width and height of axes object to compute 
    # matching arrowhead length and width
    dps = fig.dpi_scale_trans.inverted()
    bbox = ax.get_window_extent().transformed(dps)
    width, height = bbox.width, bbox.height

    # manual arrowhead width and length
    hw = 1./20.*(ymax-ymin) 
    hl = 1./20.*(xmax-xmin)
    lw = 1. # axis line width
    ohg = 0.3 # arrow overhang

    # compute matching arrowhead length and width
    yhw = hw/(ymax-ymin)*(xmax-xmin)* height/width 
    yhl = hl/(xmax-xmin)*(ymax-ymin)* width/height

    # draw x and y axis
    ax.arrow(xmin, 0, xmax-xmin, 0., fc='k', ec='k', lw = lw, 
             head_width=hw, head_length=hl, overhang = ohg, 
             length_includes_head= True, clip_on = False) 

    ax.arrow(0, ymin, 0., ymax-ymin, fc='k', ec='k', lw = lw, 
             head_width=yhw, head_length=yhl, overhang = ohg, 
             length_includes_head= True, clip_on = False)


plt.rcParams.update({'font.size': 16})
plt.rcParams.update({'figure.figsize': (6, 6)})

xmin, xmax = xlim = -.5, 10
ymin, ymax = ylim = -.5, 10

fig, ax = plt.subplots()
ax.set(xlim=xlim, ylim=ylim, autoscale_on=False)

# background image - white to gray gradient.
#gradient_image(ax, direction=0.5, extent=(0, 1, 0, 1), transform=ax.transAxes,
#               cmap=plt.cm.Greys, cmap_range=(0.0, 0.8))

x_line = np.linspace(xmin, xmax)

x = [2, 5, 2, 5]
y = [5, 5, 2, 2]
labels = ["A", "B", "C", "D"]
plt.scatter(x, y, c = "k")

for i in range(len(x)):
    plt.text(x[i]- 0.4, y[i] + 0.2, labels[i])
    
plt.plot(x_line, 5.5 - x_line, c="k", linestyle="-.")
plt.plot(x_line, 8.5 - x_line, c="k", linestyle="-")

plt.text(2.5, 3.5, "$r_1$")
plt.text(5.5, 3.5, "$r_2$")

plt.text(6, 7, "$T=0$")
plt.text(0.5, 0.5, "$T=1$")

plt.xlabel("X", labelpad = 5)
plt.ylabel("Z", rotation=0, labelpad=10)  

arrowed_spines(fig, ax)

plt.savefig("C:/Users/Riku_L/bachelors-thesis/paper/img/leniency_figure")

plt.show()
